.. _lab_system:

System Info
============

.. image:: ../_static/integrations/os.png
    :align: right
    :width: 200px
    :target: javascript:void(0);

qBraid Lab uses a Linux-based OS. It provides terminals with full support for bash shells, and comes with a number of
the most relevant software packages, programs, and tools pre-installed to help optimize the quantum developer's workflow.

To discuss projects with specific system requirements, `contact us <https://qbraid.com/contact-us/>`_.

.. seealso::

    - `Jupyter Docker Stacks <https://github.com/jupyter/docker-stacks>`_
    - `JupyterLab Terminals <https://jupyterlab.readthedocs.io/en/stable/user/terminal.html>`_


Operating System
-----------------

- `Amazon Linux 2 <https://aws.amazon.com/amazon-linux-2/>`_
- `Ubuntu 20.04.4 LTS (Focal Fossa) <https://releases.ubuntu.com/20.04/>`_


GNU Packages
-------------

- `bash <https://www.gnu.org/software/bash/>`_
- `wget <https://www.gnu.org/software/wget/>`_
- `grep <https://www.gnu.org/software/grep/>`_
- `sed <https://www.gnu.org/software/sed/>`_


Developer Tools
----------------

- `git <https://git-scm.com/>`_
- `curl <https://github.com/curl/curl>`_


Package Managers
-----------------

- `conda <https://docs.conda.io/en/latest/>`_
- `pip <https://pip.pypa.io/en/stable/>`_
- `npm <https://docs.npmjs.com/>`_


Text Editors
-------------

- `nano <https://www.nano-editor.org/>`_
- `vim <https://www.vim.org/>`_
- `vim OpenQASM Plugin <https://github.com/openqasm/openqasm.vim>`_


Frameworks & Libraries
-----------------------

- `Node.js <https://nodejs.org/en/>`_ 
- `Microsoft .NET <https://docs.microsoft.com/en-us/dotnet/>`_
- `Microsoft .NET SDK <https://docs.microsoft.com/en-us/dotnet/core/sdk>`_
- `Microsoft IQ# <https://docs.microsoft.com/en-us/dotnet/api/microsoft.quantum.iqsharp?view=quantum-dotnet-latest>`_


Cross-platform Tools
---------------------

- `qBraid CLI <../cli/qbraid.html>`_
- `AWS CLI <https://docs.aws.amazon.com/cli/latest/reference/>`_
- `Azure CLI <https://docs.microsoft.com/en-us/cli/azure/>`_
- `Azure CLI quantum extension <https://docs.microsoft.com/en-us/cli/azure/quantum?view=azure-cli-latest>`_
- `Microsoft .NET CLI <https://docs.microsoft.com/en-us/dotnet/core/tools/>`_


.. note::
    Support for the above-listed frameworks, libraries, and cross-platform tools may vary based on your qBraid subscription tier.
    Visit `account.qbraid.com/billing <https://account.qbraid.com/billing>`_ to learn more.